<template>
  <div class="app-container">
   <el-row :gutter="5">
     <el-col :span="6">
       <el-card shadow="never">
         <span class="head-font">工位编号 : {{headContent.processesCode}}</span>
       </el-card>
     </el-col>
     <el-col :span="6">
       <el-card shadow="never">
         <span class="head-font">工位名称 : {{headContent.processesName}}</span>
       </el-card>
     </el-col>
     <el-col :span="12">
       <el-card shadow="never">
         <span class="head-font">总成编码 : {{headContent.sfcCode}}</span>
         <el-input v-model="content" style="float: right;width: 150px;" placeholder="请输入内容"></el-input>
         <el-button @click="scanCompleted" style="float: right" type="primary">扫码完成</el-button>
         <el-button @click="clearClick" style="float: right" type="danger">清除</el-button>
       </el-card>
     </el-col>

   </el-row>
   <el-row :gutter="5" style="margin-top: 5px">
     <el-col :span="6" >
       <el-card class="bottom-card">
         <div slot="header" class="clearfix">
           <i class="el-icon-tickets"></i>
           <span style="font-weight: bold">当前工件信息</span>
         </div>
         <el-descriptions :column="1" :label-style="{'font-size': '15px'}" border :content-style="{'min-width': '150px'}">
           <el-descriptions-item label="工单编号">
               <span>{{workpieceInformation.workOrderCode}}</span>
           </el-descriptions-item>
           <el-descriptions-item label="产品编号">
             <span>{{workpieceInformation.productCode}}</span>
           </el-descriptions-item>
           <el-descriptions-item label="产品型号">
             <span>{{workpieceInformation.productModel}}</span>
           </el-descriptions-item>
           <el-descriptions-item label="产品名称">
             <span>{{workpieceInformation.productName}}</span>
           </el-descriptions-item>
           <el-descriptions-item label="节拍">
             <span>{{workpieceInformation.beat}}</span>
           </el-descriptions-item>
         </el-descriptions>
         <el-divider></el-divider>
         <el-row>
           <el-col :span="12">
             <el-button class="circle-button" :class="cakeLamp.plcState ? 'circle-green-animate':'circle-red'" circle></el-button>
             <span style="display: none">{{cakeLamp.plcState}}</span>
             <span>&nbsp;PLC状态</span>
           </el-col>
           <el-col :span="12">
             <el-button class="circle-button" :class="cakeLamp.scannerState ? 'circle-green-animate':'circle-red'" circle></el-button>
             <span style="display: none">{{cakeLamp.scannerState}}</span>
             <span>&nbsp;扫码枪状态</span>
           </el-col>
         </el-row>
         <el-row style="margin-top: 20px">
           <el-col :span="12">
             <el-button class="circle-button" :class="cakeLamp.InPlace ? 'circle-green':'circle-red'" circle></el-button>
             <span style="display: none">{{cakeLamp.InPlace}}</span>
             <span>&nbsp;工件到位</span>
           </el-col>
           <el-col :span="12">
             <el-button class="circle-button" :class="cakeLamp.scanFinish ? 'circle-green':'circle-red'" circle></el-button>
             <span style="display: none">{{cakeLamp.scanFinish}}</span>
             <span>&nbsp;扫码完成</span>
           </el-col>
         </el-row>
         <el-row style="margin-top: 20px">
           <el-col :span="12">
             <el-button class="circle-button" :class="cakeLamp.startWork ? 'circle-green':'circle-red'" circle></el-button>
             <span style="display: none">{{cakeLamp.startWork}}</span>
             <span>&nbsp;开始作业</span>
           </el-col>
           <el-col :span="12">
             <el-button class="circle-button" :class="cakeLamp.release ? 'circle-green':'circle-red'" circle></el-button>
             <span style="display: none">{{cakeLamp.release}}</span>
             <span>&nbsp;允许放行</span>
           </el-col>
         </el-row>
       </el-card>

     </el-col>
     <el-col :span="18">
       <el-tabs type="border-card"  style="height: 600px" v-model="activeName" @tab-click="changeMenu">
         <el-tab-pane name="first">
           <span slot="label"> <a class="el-icon-date"></a>首页</span>
           <el-col :span="8">
             <el-table>
               <el-table-column label="序号" align="center" prop="repairIdentification" width="50px"/>
               <el-table-column label="操作内容" align="center" prop="boxCode"  width="300px"/>
             </el-table>
           </el-col>
           <el-col :span="16">
             <el-image style="height: 520px;width: 100%" :src="imgSrc"></el-image>
           </el-col>
         </el-tab-pane>
         <el-tab-pane name="second">
           <span slot="label"> <b class="el-icon-date"></b>物料BOM</span>
           <el-empty>
             <span slot="description">暂无数据</span>
           </el-empty>
         </el-tab-pane>
         <el-tab-pane name="third">
           <span slot="label"> <b class="el-icon-date"></b>采集清单</span>
           <el-empty>
             <span slot="description">暂无数据</span>
           </el-empty>
         </el-tab-pane>
         <el-tab-pane name="fourth">
           <span slot="label"> <b class="el-icon-date"></b>安灯状态</span>
           <el-empty>
             <span slot="description">暂无数据</span>
           </el-empty>
         </el-tab-pane>
         <el-tab-pane name="fifth">
           <span slot="label"> <b class="el-icon-date"></b>工艺配方</span>
           <el-empty>
             <span slot="description">暂无数据</span>
           </el-empty>
         </el-tab-pane>
       </el-tabs>
     </el-col>
   </el-row>
  </div>
</template>
<script>
import {listWorkReport} from "@/api/main/om/workReport/workReport";
import {listStationConf,getIpv4} from "@/api/main/sc/stationConf";

export default {
  name: "stationTerminal",
  data() {
    return {
      ipAddress: '',
      imgSrc: '',
      headContent: {
        processesCode: 'OP1010',
        processesName: '贴标机-贴码',
        sfcCode: '1000000000000001',
      },
      workpieceInformation: {
        workOrderCode: null,
        productCode: null,
        productModel: null,
        productName: null,
        beat: null,
      },
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        sfcCode: null,
      },
      cakeLamp: {
        plcState: 1, //plc
        scannerState: 1, //扫码枪
        InPlace: 0, //工件到位
        scanFinish: 0,
        startWork: 0,
        release: 0 //允许放行
      },
      content: '',
      activeName: 'first'
    }
  },
  created() {
    this.getStationConfList();
  },
  methods: {
    changeMenu(tab, event) {
      console.log(tab, event);
    },
    clearClick(){
      this.$message('这是一条清除消息提示');
      this.headContent.sfcCode = null
    },
    scanCompleted(){
      this.$message('扫码完成'+this.content);
      this.headContent.sfcCode = this.content
      this.queryParams.sfcCode = this.content
      this.getList()
      this.cakeLamp.scanFinish = 1
    },
    /** 查询报工记录 表列表 */
    getList() {
      listWorkReport(this.queryParams).then(response => {
        let rowsData = response.rows[0];
        this.workpieceInformation.workOrderCode = rowsData.workOrderCode;
        this.workpieceInformation.productCode = rowsData.productCode;
        this.workpieceInformation.productModel = rowsData.productModel;
        this.workpieceInformation.productName = rowsData.productName;
        this.timer = setInterval(() => {
          this.workpieceInformation.beat++;
        }, 1000);
      });
    },
    allowRelease(){
      clearInterval(this.timer);
      this.$message('保存节拍为'+this.workpieceInformation.beat+'秒');
    },
    /** 查询工位终端配置列表 */
    getStationConfList() {
      let queryParams = {
        ipAddress: null,
      }
      getIpv4().then(response => {
        queryParams.ipAddress = response.msg
      });
      listStationConf(queryParams).then(response => {
        let rows = response.rows[0]
        if(response.rows.length===0){
          this.$message('改ip沒有配置工序工位，請重試！');
          return
        }
        this.headContent.processesName = rows.processesName
        this.headContent.processesCode = rows.processesCode
      });
    },
  }
}

</script>
<style scoped>
.bottom-card{
  height: 600px;
}
.circle-button{
  height: 30px;
  width: 30px;
}
.circle-red {
  background-color: #e01a4f;
}
.circle-green {
  background-color: green;
}
.circle-green-animate {
  background-color: green;
  animation: circle-green-animate 2s infinite;
}
  @keyframes circle-green-animate {
    50% {
      opacity: 0.6;
    }
    0% {
      opacity: 0.2;
    }
  }
.head-font{
  font-weight: bold;
  font-size: 25px;
}
span{
  font-size: 15px;
}
</style>
<!--<template>-->
<!--  <div>-->
<!--    <el-input v-model="url" type="text" style="width: 20%" /> &nbsp; &nbsp;-->
<!--    <el-button @click="join" type="primary">连接</el-button>-->
<!--    <el-button @click="exit" type="danger">断开</el-button>-->

<!--    <br />-->
<!--    <el-input type="textarea" v-model="message" :rows="9" />-->
<!--    <el-button type="info" @click="send">发送消息</el-button>-->
<!--    <br />-->
<!--    <br />-->
<!--    <el-input type="textarea" v-model="text_content" :rows="9" /> 返回内容-->
<!--    <br />-->
<!--    <br />-->
<!--  </div>-->
<!--</template>-->

<!--<script>-->
<!--export default {-->
<!--  data() {-->
<!--    return {-->
<!--      url: "ws://127.0.0.1:8081/websocket/message",-->
<!--      message: "",-->
<!--      text_content: "",-->
<!--      ws: null,-->
<!--    };-->
<!--  },-->
<!--  methods: {-->
<!--    join() {-->
<!--      const wsuri = this.url;-->
<!--      this.ws = new WebSocket(wsuri);-->
<!--      const self = this;-->
<!--      this.ws.onopen = function (event) {-->
<!--        self.text_content = self.text_content + "已经打开连接!" + "\n";-->
<!--      };-->
<!--      this.ws.onmessage = function (event) {-->
<!--        console.log("后端发过来的消息"+event.data)-->
<!--        self.text_content = event.data + "\n";-->
<!--      };-->
<!--      this.ws.onclose = function (event) {-->
<!--        self.text_content = self.text_content + "已经关闭连接!" + "\n";-->
<!--      };-->
<!--    },-->
<!--    exit() {-->
<!--      if (this.ws) {-->
<!--        this.ws.close();-->
<!--        this.ws = null;-->
<!--      }-->
<!--    },-->
<!--    send() {-->
<!--      if (this.ws) {-->
<!--        this.ws.send(this.message);-->
<!--      } else {-->
<!--        alert("未连接到服务器");-->
<!--      }-->
<!--    },-->
<!--  },-->
<!--};-->
<!--</script>-->

